@@ -40,6 +40,10 @@ file:../caniusepython3#egg=caniusepython3
 file:../../lib/project
 """
 
+EXAMPLE_EXTRA_REQUIREMENTS = """
+testingstuff
+"""
+
 EXAMPLE_METADATA = """Metadata-Version: 1.2
 Name: CLVault
 Version: 0.5
@@ -54,11 +58,23 @@ Requires-Dist: bar
 Platform: UNKNOWN
 """
 
+EXAMPLE_EXTRA_METADATA = """Metadata-Version: 1.2
+Name: ExtraTest
+Version: 0.5
+Summary: Just for testing
+Home-page: nowhere
+Author: nobody
+License: Apache
+Requires-Dist: baz
+"""
+
 class CLITests(unittest.TestCase):
 
     expected_requirements = frozenset(['FooProject', 'Fizzy', 'PickyThing',
                                        'Hello'])
+    expected_extra_requirements = frozenset(['testingstuff'])
     expected_metadata = frozenset(['foo', 'bar'])
+    expected_extra_metadata = frozenset(['baz'])
 
     def setUp(self):
         log = logging.getLogger('ciu')
@@ -72,13 +88,30 @@ class CLITests(unittest.TestCase):
         with tempfile.NamedTemporaryFile('w') as file:
             file.write(EXAMPLE_REQUIREMENTS)
             file.flush()
-            got = ciu_main.projects_from_requirements(file.name)
+            got = ciu_main.projects_from_requirements([file.name])
         self.assertEqual(set(got), self.expected_requirements)
 
+    def test_multiple_requirements_files(self):
+        with tempfile.NamedTemporaryFile('w') as f1:
+            f1.write(EXAMPLE_REQUIREMENTS)
+            f1.flush()
+            with tempfile.NamedTemporaryFile('w') as f2:
+                f2.write(EXAMPLE_EXTRA_REQUIREMENTS)
+                f2.flush()
+                got = ciu_main.projects_from_requirements([f1.name, f2.name])
+        want = self.expected_requirements.union(self.expected_extra_requirements)
+        self.assertEqual(set(got), want)
+
     def test_metadata(self):
-        got = ciu_main.projects_from_metadata(EXAMPLE_METADATA)
+        got = ciu_main.projects_from_metadata([EXAMPLE_METADATA])
         self.assertEqual(set(got), self.expected_metadata)
 
+    def test_multiple_metadata(self):
+        got = ciu_main.projects_from_metadata([EXAMPLE_METADATA,
+                                               EXAMPLE_EXTRA_METADATA])
+        want = self.expected_metadata.union(self.expected_extra_metadata)
+        self.assertEqual(set(got), want)
+
     def test_cli_for_requirements(self):
         with tempfile.NamedTemporaryFile('w') as file:
             file.write(EXAMPLE_REQUIREMENTS)
@@ -96,7 +129,7 @@ class CLITests(unittest.TestCase):
         self.assertEqual(set(got), self.expected_metadata)
 
     def test_cli_for_projects(self):
-        args = ['--projects', 'foo,bar']
+        args = ['--projects', 'foo', 'bar']
         got = ciu_main.projects_from_cli(args)
         self.assertEqual(set(got), frozenset(['foo', 'bar']))
 
@@ -110,7 +143,7 @@ class CLITests(unittest.TestCase):
                 'their transition:')
         self.assertEqual(messages[1], want)
 
-    def test_message_plural(self):
+    def test_message_singular(self):
         blockers = [['A']]
         messages = ciu_main.message(blockers)
         self.assertEqual(2, len(messages))
@@ -148,6 +181,10 @@ class CLITests(unittest.TestCase):
             mock.call("Missing 'requirements', 'metadata', or 'projects'"),
             parser_error.call_args)
 
+    def test_verbose_output(self):
+        ciu_main.projects_from_cli(['-v', '-p', 'ipython'])
+        self.assertTrue(logging.getLogger('ciu').isEnabledFor(logging.INFO))
+
 
 #@unittest.skip('faster testing')
 class NetworkTests(unittest.TestCase):
@@ -156,7 +193,7 @@ class NetworkTests(unittest.TestCase):
     def test_e2e(self):
         # Make sure at least one project that will never be in Python 3 is
         # included.
-        args = '--projects', 'numpy,scipy,matplotlib,ipython,paste'
+        args = '--projects', 'numpy', 'scipy', 'matplotlib', 'ipython', 'paste'
         ciu_main.main(args)
 
 
